#
# spec file for package perl-Text-BibTeX
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Text-BibTeX
Name:           perl-Text-BibTeX
Version:        0.900.0
Release:        1.1
# 0.90 -> normalize -> 0.900.0
%define cpan_version 0.90
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Interface to read and parse BibTeX files
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/A/AM/AMBS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
Patch0:         manual-pages-for-libbtparse.patch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Capture::Tiny) >= 0.06
BuildRequires:  perl(Config::AutoConf) >= 0.320
BuildRequires:  perl(ExtUtils::CBuilder) >= 0.27
BuildRequires:  perl(ExtUtils::LibBuilder) >= 0.90.0
BuildRequires:  perl(Module::Build) >= 0.3603
BuildRequires:  perl(Scalar::Util) >= 1.42
Requires:       perl(Scalar::Util) >= 1.42
Provides:       perl(Text::BibTeX) = %{version}
Provides:       perl(Text::BibTeX::BibEntry) = 0.88
Provides:       perl(Text::BibTeX::BibFormat) = 0.88
Provides:       perl(Text::BibTeX::BibSort) = 0.88
Provides:       perl(Text::BibTeX::BibStructure) = 0.88
Provides:       perl(Text::BibTeX::Entry) = 0.88
Provides:       perl(Text::BibTeX::File) = 0.88
Provides:       perl(Text::BibTeX::Name) = 0.88
Provides:       perl(Text::BibTeX::NameFormat) = 0.88
Provides:       perl(Text::BibTeX::SimpleValue) = 0.88
Provides:       perl(Text::BibTeX::Structure) = 0.88
Provides:       perl(Text::BibTeX::StructuredEntry) = 0.88
Provides:       perl(Text::BibTeX::Value) = 0.88
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  glibc-devel

%package        devel
Summary:        C library for parsing and processing BibTeX files
Group:          Development/Libraries/Other
Provides:       %{name}:%{_libdir}/libbtparse.so

%description    devel
The libbtparse is a C library for parsing and processing BibTeX files.
Note that the interface provided by libbtparse, while complete, is fairly
low-level.  If you have more sophisticated needs, you might be interested
the "Text::BibTeX" module for Perl.


# MANUAL END
%description
The 'Text::BibTeX' module serves mainly as a high-level introduction to the
'Text::BibTeX' library, for both code and documentation purposes. The code
loads the two fundamental modules for processing BibTeX files
('Text::BibTeX::File' and 'Text::BibTeX::Entry'), and this documentation
gives a broad overview of the whole library that isn't available in the
documentation for the individual modules that comprise it.

In addition, the 'Text::BibTeX' module provides a number of miscellaneous
functions that are useful in processing BibTeX data (especially the kind
that comes from bibliographies as defined by BibTeX 0.99, rather than
generic database files). These functions don't generally fit in the
object-oriented class hierarchy centred around the 'Text::BibTeX::Entry'
class, mainly because they are specific to bibliographic data and operate
on generic strings (rather than being tied to a particular BibTeX entry).
These are also documented here, in "MISCELLANEOUS FUNCTIONS".

Note that every module described here begins with the 'Text::BibTeX'
prefix. For brevity, I have dropped this prefix from most class and module
names in the rest of this manual page (and in most of the other manual
pages in the library).

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Build.PL --installdirs=vendor optimize="%{optflags}"
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README README.OLD THANKS
%exclude %{_mandir}/man3/*.3.gz

%files devel
%defattr(-,root,root,755)
%{_libdir}/libbtparse.so
%{_mandir}/man3/*.3%{?ext_man}
%{_includedir}/btparse.h

%post devel -p /sbin/ldconfig
%postun devel -p /sbin/ldconfig

%changelog
* Wed Jan 22 2025 Tina Müller <timueller+perl@suse.de>
- updated to 0.900.0 (0.90)
  see /usr/share/doc/packages/perl-Text-BibTeX/Changes
  0.90 2025-01-06
  * Added support to Haiku OS (thanks to Joachim Mairböc
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Wed Jan 25 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.89
  see /usr/share/doc/packages/perl-Text-BibTeX/Changes
  0.89 2023-01-24
  * Fix Config::AutoConf dependency version
* Mon Jun 17 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- update to 0.88
  see /usr/share/doc/packages/perl-Text-BibTeX/Changes
  0.88 2019-04-29
  * Make namebug.c compile with non std99 compiler.
  0.87 2019-04-06
  * Fix 0.86 release
  0.86 2019-03-31
  * Install btparse.h header file (Alberto Simões)
  * Fix compilation issues with some compilers (Tobias Schlemmer)
  * Fix some crashes and malfunctinos in bt_format_name and bt_split_name (Tobias Schlemmer)
  * Issue warnings for unmatched braces (Tobias Schlemmer)
- Updated URL to MetaCPAN
- Added missing btparse.h to the devel package
- Updated spec file with spec-cleaner
* Fri Apr 13 2018 werner@suse.de
- updated to 0.85
  see /usr/share/doc/packages/perl-Text-BibTeX/Changes
  0.85 2017-08-31
  * FreeBSD includes a definition of strlcat, so no need to redefine it.
  0.84 2017-08-31
  * Further buffer overflow fixes.
  * Spellchecking fixes by Julián Moreno Patiño, Lucas Kanashiro, and
    Gregor Herrmann (debian community)
  0.83 2017-08-28
  * Remove unecessary depedency to YAML.
  * Fix further buffer overflow situations.
  0.82 2017-08-27
  * Fix buffer overflow (thanks to Hamid Ebadi).
  * Hide error messages on tests, and use them for testing purposes.
  0.81 2017-07-19
  * Fix issue with NameFormat and unitialized join-tokens.
    (thanks to Karl Wette for the bug report).
* Wed May 31 2017 werner@suse.de
- Remove patches now upstream
  * Text-BibTeX-rpmlint.patch
  * perl-Text-BibTeX-uninit.patch
- Add file cpanspec.yml
- Make if build
- Add patch manual-pages-for-libbtparse.patch to get API manual
  pages for libbtparse into third section as well
- Split package for libbtparse.so off from main package
* Thu May 25 2017 coolo@suse.com
- updated to 0.80
  see /usr/share/doc/packages/perl-Text-BibTeX/Changes
  0.80 2017-03-25
  * Fix tests in order to work without dot in @INC (thanks Kent Fredric for the bug report)
  0.79 2017-03-13
  * Further fixes to allow the parse of multiple files (Karl Wette).
  0.78 2017-01-10
  * Fixed some issues with uninitialized arrays and s390
  * Fixed test with fileno (thanks to Karl Wette).
  * Allow state of btparse parser to be reset, for parsing multiple files (Karl Wette):
  - bt_parse_entry(): reset parser state if infile == NULL
  - BibTeX.xs: add _reset_parse(), _reset_parse_s() methods to Text::BibTeX::Entry
  - Text::BibTeX::Entry: allow new() or parse() with undefined filehandle; calls _reset_parse()
  - Text::BibTeX::Entry: allow new() or parse_s() with undefined text; calls _reset_parse_s()
  - Text::BibTeX::File: close() calls Text::BibTeX::Entry->new($filename, undef) to reset parser
  0.77 2016-09-20
  * Fixes for testing and installing on Darwin (install_name issues).
    Thanks to Nuno "smash" Carvalho for the report and debug help.
  0.76 2016-07-06
  * Added 'reset_macros' option to Text::BibTeX::File, in order
    to remove all defined macros (except months)
  0.76_02 2016-07-05
  * Fix issue with binmode not being copied in Clone method.
  * Make month abbreviations available always, and not only when
    using Text::BibTeX::Bib.
  * Added docs to supported options for Text::BibTeX::Entry.
  0.76_01 2016-07-04
  * Solved nasty bug when using lvalues as parameters (substr).
  * Added tests.
  0.75 2016-07-03
  * Stable version with bytes/utf-8 support.
  0.75_05 2016-07-02
  * Get 5.8.x back aboard;
  0.75_04 2016-07-01
  * Fixed reference to empty function name;
  0.75_03 2016-06-30
  * Rename split_list to isplit_list, and creaed split_list wrapper;
  * Added normalization option;
  0.75_02 2016-06-25
  * Minor fix for some perl version parsing problems.
  0.75_01 2016-06-24
  * Added binmode option. Should allow unicode handling directly.
  0.74 2016-06-15
  * Get perl 5.8.x back.
  0.73 2016-06-14
  * Change some documentation in order to use ->new method, instead
    of older 'new Class()' approach;
  * Add sensible default values to Text::BibTeX::NameFormat to reduce
    the amount of segmentation faults for users forgetting arguments.
* Tue May 31 2016 pjanouch@suse.de
- updated to 0.72
  see /usr/share/doc/packages/perl-Text-BibTeX/Changes
  0.72 2016-04-19
  * Added clone() method to Text::BibTeX::Entry
  0.71 2015-05-28
  * Fix segmentation fault when btparse fails parsing a long
    entry. Thanks to Dale Evans.
  * Stop using UNIVERSAL (5.21.3 requirement).
    Thanks to Jitka Plesnikova
- removed perl-Text-BibTeX-libdir.patch since it's been upstreamed
* Fri Sep 19 2014 coolo@suse.com
- updated to 0.70
  * Added metadata for metacpan
* Fri Jun 20 2014 schwab@linux-m68k.org
- perl-Text-BibTeX-uninit.patch: Fix use of unitialized memory
- update to 0.69
  * Replacement for islower() which understands all Unicode 6.2.0
    chars with "LOWERCASE" property
  * Fixes for UTF-8 handling of combining marks
* Sun Mar  3 2013 schwab@suse.de
- Add aarch64 to the list of lib64 platforms
* Mon Dec 10 2012 ro@suse.de
- fix libdir for s390x as well
- update to 0.66
  * Fix a segmentation fault with strcat and no string limit
  * Patch to support @ and ~ in names
  * Patch to expand macro size limit
* Fri May 25 2012 dvaleev@suse.com
- fix ppc64 libdir
* Mon May 21 2012 werner@suse.de
- Make perl-Text-BibTeX from devel:languages:perl:CPAN-T build for
  Factory that is make it build and survive rpmlint
- Do not forget the libbtparse.so as this is required
